
#include <Arduino.h>
#include "DDS_tracking.h"
#include "AD9851.h"

// make sure you have selected the correct defines for Arduino board
// and the correct DDS type in DDS_tracking.h


DDS dds;

//                 Mega         Uno 
byte resetPin;	// default 23 - 10
byte dataPin;		// default 25 - 11
byte updatePin;	// default 27 -  9
byte clockPin;	// default 31 - 13

bool setSpotFlag;

String ddsType = "No DDS set";

void setup(void)
{
	Serial.begin(115200);
	Serial.println("Starting setup");

	setDDSpins();

 #ifdef AD9851
   dds.enableMultiplier = true;
   dds.clockFrequency = 180000000.0;
   ddsType = "DDS is AD9851";
 #endif
 
 #ifdef AD9850
   dds.enableMultiplier = false;
   dds.clockFrequency = 125000000.0;
   ddsType = "DDS is AD9850";
  #endif	

  Serial.println(ddsType);

  dds.quad = false;
  dds.enableMultiplier = true;

  // should not be needed, but allow everthing to settle down
  delay(100);

  dds.reset();
  dds.sendFrequency(dds.frequency);
  dds.updateFrequency();
  
  setSpotFlag = true;

	sei();
  Serial.println("Setup complete");
}

void loop(void)
{
  if (setSpotFlag)
  {
    // default frequency  - 1MHZ
	  dds.frequency = 1000000.0;
    dds.sendFrequency(dds.frequency);
    dds.updateFrequency();
    setSpotFlag = false;
  }
}

void setDDSpins()
{
  #ifdef Arduino_UNO
    updatePin = 9;
    resetPin  = 10;
    dataPin   = 11;
    clockPin  = 13;
	  Serial.println("Pins set for Uno");
  #endif

  #ifdef Mega2560
    updatePin = 27;
    resetPin  = 23;
    dataPin   = 25;
    clockPin  = 31;
	  Serial.println("Pins set for Mega2560");
#endif

  dds.resetPin = resetPin;
  dds.dataPin = dataPin;
  dds.updatePin = updatePin;
  dds.clkPin = clockPin;

  pinMode(dds.resetPin, OUTPUT);
  pinMode(dds.dataPin, OUTPUT);
  pinMode(dds.updatePin, OUTPUT);
  pinMode(dds.clkPin, OUTPUT);
}


